@@ -6,6 +6,10 @@ sentry.web.forms.accounts
 :license: BSD, see LICENSE for more details.
 """
 
+import pytz
+
+from datetime import datetime
+
 from django import forms
 from django.contrib.auth import authenticate
 from django.utils.translation import ugettext_lazy as _
@@ -14,6 +18,21 @@ from sentry.constants import EMPTY_PASSWORD_VALUES, LANGUAGES
 from sentry.models import UserOption, User
 
 
+def _get_timezone_choices():
+    results = []
+    for tz in pytz.common_timezones:
+        now = datetime.now(pytz.timezone(tz))
+        offset = now.strftime('%z')
+        results.append((int(offset), tz, '(GMT%s) %s' % (offset, tz)))
+    results.sort()
+
+    for i in xrange(len(results)):
+        results[i] = results[i][1:]
+    return results
+
+TIMEZONE_CHOICES = _get_timezone_choices()
+
+
 class RegistrationForm(forms.ModelForm):
     email = forms.EmailField()
     password = forms.CharField(widget=forms.PasswordInput)
@@ -124,25 +143,24 @@ class AccountSettingsForm(forms.Form):
 
 
 class AppearanceSettingsForm(forms.Form):
-    language = forms.ChoiceField(label=_('Language'), choices=LANGUAGES, required=False)
-    stacktrace_order = forms.ChoiceField(label=_('Stacktrace order'), choices=(
-        ('-1', _('Default (let Sentry decide)')),
-        ('1', _('Most recent call last')),
-        ('2', _('Most recent call first')),
-    ), help_text=_('Choose the default ordering of frames in stacktraces.'), required=False)
+    language = forms.ChoiceField(
+        label=_('Language'), choices=LANGUAGES, required=False)
+    stacktrace_order = forms.ChoiceField(
+        label=_('Stacktrace order'), choices=(
+            ('-1', _('Default (let Sentry decide)')),
+            ('1', _('Most recent call last')),
+            ('2', _('Most recent call first')),
+        ), help_text=_('Choose the default ordering of frames in stacktraces.'),
+        required=False)
+    timezone = forms.ChoiceField(
+        label=_('Time zone'), choices=TIMEZONE_CHOICES, required=False,
+        widget=forms.Select(attrs={'class': 'span4'}))
 
     def __init__(self, user, *args, **kwargs):
         self.user = user
         super(AppearanceSettingsForm, self).__init__(*args, **kwargs)
 
     def save(self):
-        # if self.cleaned_data['new_password2']:
-        #     self.user.set_password(self.cleaned_data['new_password1'])
-        # self.user.first_name = self.cleaned_data['first_name']
-        # self.user.email = self.cleaned_data['email']
-        # if commit:
-        #     self.user.save()
-
         # Save user language
         UserOption.objects.set_value(
             user=self.user,
@@ -159,6 +177,14 @@ class AppearanceSettingsForm(forms.Form):
             value=self.cleaned_data['stacktrace_order'],
         )
 
+        # Save time zone options
+        UserOption.objects.set_value(
+            user=self.user,
+            project=None,
+            key='timezone',
+            value=self.cleaned_data['timezone'],
+        )
+
         return self.user
 
 
